chromoR-package:
Analysis of chromosomal interactions data (Hi-C data)
Description
ChromoR combines wavelet change point with Bayes Factor, for useful correction,
segmentation and comparison of Hi-C contact maps.
It provides a user friendly software solution, addressing the entire statistical
pipeline required for the analysis of chromosomal interactions data.
Arguments
Details
Package:
chromoR
Type:
Package
Version:
1.0
Date:
2014-02-07
License:
GPL-2
For an easy start with chromoR, check out the documentation and examples for
correctCIM, compareCIM and segmentCIM
See also http://www.cl.cam.ac.uk/~ys388/chromoR/ for more examples and data sets.